# Copyright 1999-2006 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $

## 2008.05.09: Note: eliminated "here-doc-configure", now use "shell-var-mimik"
## 2008.05.11: need to install as before: all stuff except init.d-script to
##	/usr/lib/hobbit; otherwise (some stuff to /etc/hobbit/) a chown-error for
##	some directories is generated by hobbit's "make install"-routine (e.g. for
##	"www/" and "web/".
##
## 2009.08.13: this is my messy ebuild for 4.2.0 + all-in-one + custom user_channel.patches
##	for VMware-Monitoring-tests

inherit eutils

MY_P="${P%_*}"
DESCRIPTION="hobbit monitoring system -- sucessor of big-brother"
HOMEPAGE="http://hobbitmon.sourceforge.net/"
SRC_URI="mirror://sourceforge/hobbitmon/${MY_P}.tar.gz"

LICENSE="GPL-2"
SLOT="0"
KEYWORDS="x86"
IUSE="server"

DEPEND="server? ( dev-libs/libpcre
	net-analyzer/fping
	net-analyzer/rrdtool
	dev-libs/openssl
	net-nds/openldap )"
RDEPEND="$DEPEND"

S="${WORKDIR}/${MY_P}"

pkg_preinst() {
	einfo "packages needed for specific tasks:"
	einfo "package             pgm needed             for ..."
	einfo "---------------------------------------------------------------"
	einfo "net-misc/openntpd   -                    time synchronization"
	einfo "net-misc/ntp        ntpdate              \"ntp\" net-test"
	einfo "glibc?              rpcinfo              \"nfs|rpc\" net-tests"
	einfo "net-snmp            -                    for snmp-tests (in DEPEND)"
	echo
	einfo "sudo                sudo                 for vserver- and raid-exts"
	einfo "sysstat             iostat               for vmio-ext"
	epause 5
}

pkg_setup() {
	enewgroup hobbit 2005
	enewuser hobbit 2005 /bin/bash /usr/lib/hobbit hobbit,root
}

src_unpack() {
	unpack ${A}
	cd ${S}

	#epatch ${FILESDIR}/allinone-2006-10-03.patch.gz || die "patch failed"
	epatch ${FILESDIR}/allinone-2007-02-09.patch.gz || die "patch failed"

	epatch ${FILESDIR}/close_user_channel.patch || die "close_user_channel.patch failed"

	epatch ${FILESDIR}/hobbit-4.2.0-pagetitlelinks-font.patch ||\
		die "pagetitlelinks-font.patch failed"


	## on vserver-guests there is no 127.0.0.1:
	sed -i.org \
		-e 's/127.0.0.1/localhost/' build/fping.sh ||\
		die "127.0.0.1 -> localhost sed failed"
}

src_compile() {
	## TODO: need to find a nice way to configure -- for now we
	## just copy an interactively created Makefile
	#./configure
	if use server; then
		USEHOBBITPING=n \
		ENABLESSL=y \
		ENABLELDAP=y \
		ENABLELDAPSSL=y \
		BBUSER=hobbit \
		BBTOPDIR=/usr/lib/hobbit \
		BBVAR=/usr/lib/hobbit/data \
		BBHOSTURL=/hobbit \
		CGIDIR=/usr/lib/hobbit/cgi-bin \
		BBCGIURL=/hobbit-cgi \
		SECURECGIDIR=/usr/lib/hobbit/cgi-secure \
		SECUREBBCGIURL=/hobbit-seccgi \
		HTTPDGID=hobbit \
		BBLOGDIR=/var/log/hobbit \
		BBHOSTNAME=localhost \
		BBHOSTIP=127.0.0.1 \
		MANROOT=/usr/share/man \
		INSTALLBINDIR=/usr/lib/hobbit/server/bin \
		INSTALLETCDIR=/usr/lib/hobbit/server/etc \
		INSTALLWEBDIR=/usr/lib/hobbit/server/web \
		INSTALLEXTDIR=/usr/lib/hobbit/server/ext \
		INSTALLTMPDIR=/usr/lib/hobbit/server/tmp \
		INSTALLWWWDIR=/usr/lib/hobbit/server/www \
		./configure --server
	else
		USEHOBBITPING=n \
		ENABLESSL=y \
		ENABLELDAP=y \
		ENABLELDAPSSL=y \
		BBUSER=hobbit \
		BBTOPDIR=/usr/lib/hobbit \
		BBVAR=/usr/lib/hobbit/data \
		BBHOSTURL=/hobbit \
		CGIDIR=/usr/lib/hobbit/cgi-bin \
		BBCGIURL=/hobbit-cgi \
		SECURECGIDIR=/usr/lib/hobbit/cgi-secure \
		SECUREBBCGIURL=/hobbit-seccgi \
		HTTPDGID=hobbit \
		BBLOGDIR=/var/log/hobbit \
		BBHOSTNAME=localhost \
		BBHOSTIP=127.0.0.1 \
		MANROOT=/usr/share/man \
		INSTALLBINDIR=/usr/lib/hobbit/client/bin \
		INSTALLETCDIR=/usr/lib/hobbit/client/etc \
		INSTALLWEBDIR=/usr/lib/hobbit/client/web \
		INSTALLEXTDIR=/usr/lib/hobbit/client/ext \
		INSTALLTMPDIR=/usr/lib/hobbit/client/tmp \
		INSTALLWWWDIR=/usr/lib/hobbit/client/www \
		./configure --client
	fi
	PKGBUILD=1 make || die "compile failed"
}

src_install() {
	local dirtokeep_base="/usr/lib/hobbit/"
	local dirtokeep="data/{acks,disabled,hist,histlogs,hostdata,logs,rrd} \
		tmp/ \
		www/{snap,html,wml,rep,notes} \
		client/{ext,logs,tmp}"

	PKGBUILD=1 make INSTALLROOT=${D} install || die "install failed"

	## make sure empty dirs are installed:
	for my_dir in $(eval echo "${dirtokeep}")
	do
		keepdir ${dirtokeep_base}/${my_dir}
	done

	if use server; then
		newinitd ${FILESDIR}/hobbitd.initd hobbitd || die "init.d/hobbitd failed"
	else
		newinitd ${FILESDIR}/hobbitc.initd hobbitc || die "init.d/hobbitc failed"
		newconfd ${FILESDIR}/hobbitc.confd hobbitc || die "conf.d/hobbitc failed"
		#rm -r {D}/usr/lib/hobbit/data || die "rm of data-dir failed"
		#rm -r {D}/usr/lib/hobbit/server || die "rm of server-dir failed"
	fi

	## fix ownerships:
	for ii in $(find ${D}/usr/lib/hobbit/)
	do
		chown hobbit:hobbit ${ii} || die "chown for \"${ii}\" failed"
	done
	fowners hobbit:hobbit /var/log/hobbit ||\
		die "fowner for /var/log/hobbit failed"

	dodoc Changes README README.CLIENT RELEASENOTES

	## install contrib-stuff:
	docinto contrib
	dodoc contrib/*
}

pkg_postinst() {
	einfo "extend you CONFIG_PROTECT to include"
	einfo "  /usr/lib/hobbit/server/etc/ /usr/lib/hobbit/server/ext/ \\"
	einfo "    /usr/lib/hobbit/client/etc/"
	einfo "  e.g. like this:"
	einfo "    CONFIG_PROTECT=\"\${CONFIG_PROTECT} /usr/lib/hobbit/client/etc/\""
	einfo "  for client-only-install"
	echo
	einfo "if you only built the client (no \"server\" USE-flag specified)"
	einfo "you can omit the server-part above."
	echo
	einfo "adjust /usr/lib/hobbit/client/etc/hobbitclient.cfg, in particular"
	einfo "  BBDISP"
	einfo "has to point to you hobbit-server!"
}
