# Copyright 1999-2006 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
# $Header: $

## compiles fine :)
## 2008.05.11: try to clone working hobbit-4.2.0_p2-r3.ebuild to snapshot ...
## 2008.05.24: added install of hobbit-snmpmibs.cfg
##				general note: this version runs _relatively_ stable (one hang of
##				hobbitd up to now)
## 2008.12.08: copy to xymon-4.2.2_rc1.ebuild
##	- compiles fine
## 2008.12.09: xymon-4.2.2_rc1-r1.ebuild
##	- try to eliminate "hobbit" in paths and usernames
## 2009.01.21: copy from xymon-4.2.2_rc1-r1.ebuild (now final version available :)
##	- 

inherit eutils

MY_P="${P/_rc/-RC}"
DESCRIPTION="xymon (formerly hobbit) monitoring system -- sucessor of big-brother"
HOMEPAGE="http://hobbitmon.sourceforge.net/"
SRC_URI="mirror://sourceforge/hobbitmon/${MY_P}.tar.gz"

LICENSE="GPL-2"
SLOT="0"
KEYWORDS="x86 amd64"
IUSE="server"

DEPEND="server? ( dev-libs/libpcre
	net-analyzer/fping
	net-analyzer/rrdtool
	dev-libs/openssl
	net-nds/openldap
	net-analyzer/net-snmp )"
RDEPEND="$DEPEND"

S="${WORKDIR}/${MY_P}"

pkg_preinst() {
	einfo "packages needed for specific tasks:"
	einfo "package             pgm needed             for ..."
	einfo "---------------------------------------------------------------"
	einfo "net-misc/openntpd   -                    time synchronization"
	einfo "net-misc/ntp        ntpdate              \"ntp\" net-test"
	einfo "glibc?              rpcinfo              \"nfs|rpc\" net-tests"
	einfo "net-snmp            -                    for snmp-tests (in DEPEND)"
	echo
	einfo "sudo                sudo                 for vserver- and raid-exts"
	einfo "sysstat             iostat               for vmio-ext"
	epause 5
}

pkg_setup() {
	#enewgroup hobbit 2005
	enewgroup xymon 2005
	enewuser xymon 2005 /bin/bash /usr/lib/xymon xymon,root
}

src_unpack() {
	unpack ${A}
	cd ${S}

	## this is a snapshot-ebuild, so no all-in-one-patch needed ;)
	#epatch ${FILESDIR}/allinone-2006-10-03.patch.gz || die "patch failed"
	#epatch ${FILESDIR}/allinone-2007-02-09.patch.gz || die "patch failed"

	## on vserver-guests there is no 127.0.0.1:
	sed -i.org \
		-e 's/127.0.0.1/localhost/' build/fping.sh ||\
		die "127.0.0.1 -> localhost sed failed"
}

src_compile() {
	## TODO: need to find a nice way to configure -- for now we
	## just copy an interactively created Makefile
	#./configure
	if use server; then
		USEHOBBITPING=n \
		ENABLESSL=y \
		ENABLELDAP=y \
		ENABLELDAPSSL=y \
		BBUSER=xymon \
		BBTOPDIR=/usr/lib/xymon \
		BBVAR=/usr/lib/xymon/data \
		BBHOSTURL=/xymon \
		CGIDIR=/usr/lib/xymon/cgi-bin \
		BBCGIURL=/xymon-cgi \
		SECURECGIDIR=/usr/lib/xymon/cgi-secure \
		SECUREBBCGIURL=/xymon-seccgi \
		HTTPDGID=xymon \
		BBLOGDIR=/var/log/xymon \
		BBHOSTNAME=localhost \
		BBHOSTIP=127.0.0.1 \
		MANROOT=/usr/share/man \
		INSTALLBINDIR=/usr/lib/xymon/server/bin \
		INSTALLETCDIR=/usr/lib/xymon/server/etc \
		INSTALLWEBDIR=/usr/lib/xymon/server/web \
		INSTALLEXTDIR=/usr/lib/xymon/server/ext \
		INSTALLTMPDIR=/usr/lib/xymon/server/tmp \
		INSTALLWWWDIR=/usr/lib/xymon/server/www \
		./configure --server
	else
		#LOCALCLIENT=n \
		#CLIENTONLY=y \
		CONFTYPE=server \
		USEHOBBITPING=n \
		ENABLESSL=y \
		ENABLELDAP=y \
		ENABLELDAPSSL=y \
		BBUSER=xymon \
		BBTOPDIR=/usr/lib/xymon \
		BBVAR=/usr/lib/xymon/data \
		BBHOSTURL=/xymon \
		CGIDIR=/usr/lib/xymon/cgi-bin \
		BBCGIURL=/xymon-cgi \
		SECURECGIDIR=/usr/lib/xymon/cgi-secure \
		SECUREBBCGIURL=/xymon-seccgi \
		HTTPDGID=xymon \
		BBLOGDIR=/var/log/xymon \
		BBHOSTNAME=localhost \
		BBHOSTIP=127.0.0.1 \
		MANROOT=/usr/share/man \
		INSTALLBINDIR=/usr/lib/xymon/client/bin \
		INSTALLETCDIR=/usr/lib/xymon/client/etc \
		INSTALLWEBDIR=/usr/lib/xymon/client/web \
		INSTALLEXTDIR=/usr/lib/xymon/client/ext \
		INSTALLTMPDIR=/usr/lib/xymon/client/tmp \
		INSTALLWWWDIR=/usr/lib/xymon/client/www \
		./configure --client
	fi
	PKGBUILD=1 make || die "compile failed"
}

src_install() {
	local dirtokeep_base="/usr/lib/xymon/"
	local dirtokeep="data/{acks,disabled,hist,histlogs,hostdata,logs,rrd} \
		tmp/ \
		www/{snap,html,wml,rep,notes} \
		client/{ext,logs,tmp}"

	PKGBUILD=1 make INSTALLROOT=${D} install || die "install failed"

	## make sure empty dirs are installed:
	for my_dir in $(eval echo "${dirtokeep}")
	do
		keepdir ${dirtokeep_base}/${my_dir}
	done

	if use server; then
		newinitd ${FILESDIR}/xymond.initd xymond || die "init.d/xymond failed"
		fowners xymon:xymon /var/log/xymon ||\
			die "fowner for /var/log/xymon failed"
	else
		newinitd ${FILESDIR}/xymonc.initd xymonc || die "init.d/xymonc failed"
		newconfd ${FILESDIR}/xymonc.confd xymonc || die "conf.d/xymonc failed"
		#rm -r {D}/usr/lib/xymon/data || die "rm of data-dir failed"
		#rm -r {D}/usr/lib/xymon/www || die "rm of www-dir failed"
	fi

	## fix ownerships:
	for ii in $(find ${D}/usr/lib/xymon/)
	do
		chown xymon:xymon ${ii} || die "chown for \"${ii}\" failed"
	done

	dodoc Changes README README.CLIENT RELEASENOTES

	## install contrib-stuff:
	docinto contrib
	dodoc contrib/*
}

pkg_postinst() {
	einfo "extend you CONFIG_PROTECT to include"
	einfo "  /usr/lib/xymon/server/etc/ /usr/lib/xymon/server/ext/ \\"
	einfo "    /usr/lib/xymon/client/etc/"
	einfo "  e.g. like this:"
	einfo "    CONFIG_PROTECT=\"\${CONFIG_PROTECT} /usr/lib/xymon/client/etc/\""
	einfo "  for client-only-install"
	echo
	einfo "if you only built the client (no \"server\" USE-flag specified)"
	einfo "you can omit the server-part above."
	echo
	einfo "adjust /usr/lib/xymon/client/etc/hobbitclient.cfg, in particular"
	einfo "  BBDISP"
	einfo "has to point to you xymon-server!"
}
